﻿using System.Diagnostics;
using System.Windows;
using ThinkGeo.MapSuite;
using ThinkGeo.MapSuite.Layers;
using ThinkGeo.MapSuite.Shapes;
using ThinkGeo.MapSuite.Wpf;

namespace _9588
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }

        private void map_Loaded(object sender, RoutedEventArgs e)
        {
            map.MapUnit = GeographyUnit.Meter;
            map.ZoomLevelSet = new OpenStreetMapsZoomLevelSet();

            //map.ExtentOverlay

            Proj4Projection proj4 = new Proj4Projection(4326, 3857);
            proj4.Open();

            PointShape point = new PointShape(-150, 60);
            PointShape pointInMeter = proj4.ConvertToExternalProjection(point) as PointShape;

            RectangleShape rectArdound100NM = pointInMeter.Buffer(100, GeographyUnit.Feet, DistanceUnit.NauticalMile).GetBoundingBox();            

            limitationOpenStreetMapOverlay worldOverlay = new limitationOpenStreetMapOverlay(rectArdound100NM);
            worldOverlay.TransitionEffect = TransitionEffect.None;
            worldOverlay.TileType = TileType.MultipleTile;
            map.Overlays.Add(worldOverlay);


            map.CurrentExtent = rectArdound100NM;            
            map.Refresh();
        }
    }

    public class limitationOpenStreetMapOverlay : OpenStreetMapOverlay
    {
        private RectangleShape limitationExtent;

        public limitationOpenStreetMapOverlay(RectangleShape limitationExtent) : base()
        {
            this.limitationExtent = limitationExtent;
        }

        protected override void DrawTileCore(ThinkGeo.MapSuite.Wpf.Tile tile, RectangleShape targetExtent)
        {
            if (targetExtent.Intersects(limitationExtent))
            {
                base.DrawTileCore(tile, targetExtent);
            }
            else
            {
                Debug.WriteLine("Don't draw this tile");
            }
        }
    }
}
